@@ -520,7 +520,7 @@ void ScriptInterp::error(const char *errmsg)
 
         setSymbol("script.error", errmsg);
         snprintf(evtname, sizeof(evtname), "error:%s", errmsg);
-        if(event(evtname))
+        if(scriptEvent(evtname))
                 return;
 
         if((frame[stack].script->mask & 0x02) && frame[stack].script->trap[1])
@@ -558,7 +558,15 @@ bool ScriptInterp::tryCatch(const char *id)
 	return true;
 }
 
-bool ScriptInterp::event(const char *name, bool inhereted)
+void ScriptInterp::gotoEvent(NamedEvent *evt)
+{
+        clearStack();
+        frame[stack].tranflag = frame[stack].caseflag = false;
+        frame[stack].line = frame[stack].first = evt->line;
+        image->fastBranch(this);
+}
+
+bool ScriptInterp::scriptEvent(const char *name, bool inhereted)
 {
 	char evtname[128];
 	const char *savname = name;
@@ -613,11 +621,7 @@ retry:
 		while(stack > current)
 			pull();
 
-		clearStack();
-		frame[stack].tranflag = frame[stack].caseflag = false;
-		frame[stack].line = frame[stack].first = evt->line;
-
-		image->fastBranch(this);
+		gotoEvent(evt);
 		return true;
 	}
 
