@@ -736,7 +736,7 @@ bool ScriptMethods::scrThrow(void)
 		return true;
 	}
 
-	event(++cp);
+	scriptEvent(++cp);
 	return true;
 }
 
@@ -858,7 +858,7 @@ bool ScriptMethods::scrLock(void)
 		if(locker && locker->getSequence() == lockseq)
 		{
 			snprintf(evtname, sizeof(evtname), "locked:%s", sym->id);
-			if(event(evtname))
+			if(scriptEvent(evtname))
 				return true;
 			error("lock-symbol-locked");
 			return true;
@@ -1494,7 +1494,7 @@ retry:
 	}
 	if(*label == '@' || *label == '{')
 	{
-		if(event(label + 1))
+		if(scriptEvent(label + 1))
 			return true;
 	}
 	if(*label == '^')
