@@ -1278,7 +1278,14 @@ protected:
          * @param name of event handler.
          * @param inhereted search flag.
          */
-        virtual bool event(const char *evtname, bool inheret = true);
+        bool scriptEvent(const char *evtname, bool inheret = true);
+
+	/**
+	 * Branch to a selected event record immediately.
+	 *
+	 * @param event record.
+	 */
+	void gotoEvent(NamedEvent *ev);
 
         /**
          * Set the execution interpreter to a trap identifier.  If no
